==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QWaitCondition_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qwaitcondition.h>
#include <QtCore/QVariant>
#include <QtCore/qmutex.h>
#include <QtCore/qdeadlinetimer.h>
#include <QtCore/qreadwritelock.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWaitCondition(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWaitCondition")
    QWaitCondition *_ptr = reinterpret_cast<QWaitCondition *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWaitCondition()
void __qt_construct_QWaitCondition_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWaitCondition()")
    Q_UNUSED(__java_arguments)
    QWaitCondition *__qt_this = new(__qtjambi_ptr) QWaitCondition();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QWaitCondition
void __qt_destruct_QWaitCondition(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWaitCondition")
    reinterpret_cast<QWaitCondition*>(ptr)->~QWaitCondition();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWaitCondition::QWaitCondition()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_initialize_1native__Lio_qt_core_QWaitCondition_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWaitCondition::QWaitCondition()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWaitCondition_0, sizeof(QWaitCondition), typeid(QWaitCondition), false, &deleter_QWaitCondition, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWaitCondition::wait(QMutex*,QDeadlineTimer)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wait_1native_1QMutex_1ptr_1QDeadlineTimer__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID lockedMutex0,
 QtJambiNativeID deadline1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wait(QMutex*,QDeadlineTimer)", __qt_this)
        QMutex* __qt_lockedMutex0 = QtJambiAPI::objectFromNativeId<QMutex>(lockedMutex0);
        QDeadlineTimer __qt_deadline1 = QtJambiAPI::objectReferenceFromNativeId<QDeadlineTimer>(__jni_env, deadline1);
        __java_return_value = __qt_this->wait(__qt_lockedMutex0, __qt_deadline1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWaitCondition::wait(QMutex*,ulong)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wait_1native_1QMutex_1ptr_1unsigned_1long__JJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID lockedMutex0,
 jint time1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wait(QMutex*,ulong)", __qt_this)
        QMutex* __qt_lockedMutex0 = QtJambiAPI::objectFromNativeId<QMutex>(lockedMutex0);
        __java_return_value = __qt_this->wait(__qt_lockedMutex0, static_cast<unsigned long>(time1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWaitCondition::wait(QReadWriteLock*,QDeadlineTimer)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wait_1native_1QReadWriteLock_1ptr_1QDeadlineTimer__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID lockedReadWriteLock0,
 QtJambiNativeID deadline1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wait(QReadWriteLock*,QDeadlineTimer)", __qt_this)
        QReadWriteLock* __qt_lockedReadWriteLock0 = QtJambiAPI::objectFromNativeId<QReadWriteLock>(lockedReadWriteLock0);
        QDeadlineTimer __qt_deadline1 = QtJambiAPI::objectReferenceFromNativeId<QDeadlineTimer>(__jni_env, deadline1);
        __java_return_value = __qt_this->wait(__qt_lockedReadWriteLock0, __qt_deadline1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWaitCondition::wait(QReadWriteLock*,ulong)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wait_1native_1QReadWriteLock_1ptr_1unsigned_1long__JJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID lockedReadWriteLock0,
 jint time1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wait(QReadWriteLock*,ulong)", __qt_this)
        QReadWriteLock* __qt_lockedReadWriteLock0 = QtJambiAPI::objectFromNativeId<QReadWriteLock>(lockedReadWriteLock0);
        __java_return_value = __qt_this->wait(__qt_lockedReadWriteLock0, static_cast<unsigned long>(time1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWaitCondition::wakeAll()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wakeAll_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wakeAll()", __qt_this)
        __qt_this->wakeAll();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWaitCondition::wakeOne()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wakeOne_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wakeOne()", __qt_this)
        __qt_this->wakeOne();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWaitCondition(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWaitCondition>("QWaitCondition", "io/qt/core/QWaitCondition");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWaitCondition, {
        ConstructorInfo(&__qt_construct_QWaitCondition_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWaitCondition);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QWaitCondition_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qwaitcondition.h>
#include <QtCore/QVariant>
#include <QtCore/qdeadlinetimer.h>
#include <QtCore/qmutex.h>
#include <QtCore/qreadwritelock.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWaitCondition(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWaitCondition")
    QWaitCondition *_ptr = reinterpret_cast<QWaitCondition *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWaitCondition()
void __qt_construct_QWaitCondition(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWaitCondition()")
    Q_UNUSED(__java_arguments)
    QWaitCondition *__qt_this = new(__qtjambi_ptr) QWaitCondition();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QWaitCondition::QWaitCondition()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_initialize_1native__Lio_qt_core_QWaitCondition_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWaitCondition::QWaitCondition()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWaitCondition, sizeof(QWaitCondition), typeid(QWaitCondition), false, &deleter_QWaitCondition, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QWaitCondition
void __qt_destruct_QWaitCondition(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWaitCondition")
    reinterpret_cast<QWaitCondition*>(ptr)->~QWaitCondition();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWaitCondition::wait(QMutex*,QDeadlineTimer)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wait_1native_1QMutex_1ptr_1QDeadlineTimer__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID lockedMutex0,
 QtJambiNativeID deadline1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wait(QMutex*,QDeadlineTimer)", __qt_this)
        QMutex* __qt_lockedMutex0 = QtJambiAPI::objectFromNativeId<QMutex>(lockedMutex0);
        QDeadlineTimer __qt_deadline1 = QtJambiAPI::objectReferenceFromNativeId<QDeadlineTimer>(__jni_env, deadline1);
        __java_return_value = __qt_this->wait(__qt_lockedMutex0, __qt_deadline1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWaitCondition::wait(QMutex*,ulong)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wait_1native_1QMutex_1ptr_1unsigned_1long__JJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID lockedMutex0,
 jint time1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wait(QMutex*,ulong)", __qt_this)
        QMutex* __qt_lockedMutex0 = QtJambiAPI::objectFromNativeId<QMutex>(lockedMutex0);
        __java_return_value = __qt_this->wait(__qt_lockedMutex0, static_cast<unsigned long>(time1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWaitCondition::wait(QReadWriteLock*,QDeadlineTimer)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wait_1native_1QReadWriteLock_1ptr_1QDeadlineTimer__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID lockedReadWriteLock0,
 QtJambiNativeID deadline1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wait(QReadWriteLock*,QDeadlineTimer)", __qt_this)
        QReadWriteLock* __qt_lockedReadWriteLock0 = QtJambiAPI::objectFromNativeId<QReadWriteLock>(lockedReadWriteLock0);
        QDeadlineTimer __qt_deadline1 = QtJambiAPI::objectReferenceFromNativeId<QDeadlineTimer>(__jni_env, deadline1);
        __java_return_value = __qt_this->wait(__qt_lockedReadWriteLock0, __qt_deadline1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWaitCondition::wait(QReadWriteLock*,ulong)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wait_1native_1QReadWriteLock_1ptr_1unsigned_1long__JJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID lockedReadWriteLock0,
 jint time1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wait(QReadWriteLock*,ulong)", __qt_this)
        QReadWriteLock* __qt_lockedReadWriteLock0 = QtJambiAPI::objectFromNativeId<QReadWriteLock>(lockedReadWriteLock0);
        __java_return_value = __qt_this->wait(__qt_lockedReadWriteLock0, static_cast<unsigned long>(time1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWaitCondition::wakeAll()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wakeAll_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wakeAll()", __qt_this)
        __qt_this->wakeAll();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWaitCondition::wakeOne()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QWaitCondition_wakeOne_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWaitCondition *__qt_this = QtJambiAPI::objectFromNativeId<QWaitCondition>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWaitCondition::wakeOne()", __qt_this)
        __qt_this->wakeOne();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWaitCondition(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWaitCondition>("QWaitCondition", "io/qt/core/QWaitCondition");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWaitCondition, {
        ConstructorInfo(&__qt_construct_QWaitCondition, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWaitCondition);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
